Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Wrap ¶
Wrap is an fs.FS "middleware" that wraps an fs.FS with a defaulting-file-system.
With a defaulting-file-system, there is a list of default-file-names. For example:
[]string{"default.html","default.xhtml","index.html","index.xhtml","README.md"}
This is a priortized list. With names earlier in the list having a higher priority.
And then, if the path given to the Open №1 ends in a "/", and №2 is a directory, and №3 the fs.File either implements fsdir.DirReaderAll or fs.ReadDirFile, and №4 the directory (directly) contains a file with one of the default-file-names, then that matching default-file-name is returned.
If more there is more than one match, then the highest priority one is returned.
Types ¶
This section is empty.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.